@@ -14,6 +14,7 @@
 #    under the License.
 #
 import abc
+import datetime
 import fractions
 
 from oslo_config import cfg
@@ -30,9 +31,9 @@ from voluptuous import Optional
 from voluptuous import Required
 from voluptuous import Schema
 
+from cloudkitty.dataframe import DataPoint
 from cloudkitty import utils as ck_utils
 
-
 LOG = logging.getLogger(__name__)
 
 collect_opts = [
@@ -69,6 +70,8 @@ def MetricDict(value):
 CONF_BASE_SCHEMA = {Required('metrics'): MetricDict}
 
 METRIC_BASE_SCHEMA = {
+    # Human-readable description for the CloudKitty rating type
+    Optional('description'): All(str, Length(min=1)),
     # Display unit
     Required('unit'): All(str, Length(min=1)),
     # Factor for unit converion
@@ -248,6 +251,32 @@ class BaseCollector(object, metaclass=abc.ABCMeta):
 
         return name, data
 
+    def _create_data_point(self, metric, qty, price, groupby, metadata, start):
+        unit = metric['unit']
+        if not start:
+            start = datetime.datetime.now()
+            LOG.debug("Collector [%s]. No start datetime defined for "
+                      "datapoint[unit=%s, quantity=%s, price=%s, groupby=%s, "
+                      "metadata=%s]. Therefore, we use the current time as "
+                      "the start time for this datapoint.",
+                      self.collector_name, unit, qty, price, groupby, metadata)
+
+        week_of_the_year = start.strftime("%U")
+        day_of_the_year = start.strftime("%-j")
+        month_of_the_year = start.strftime("%-m")
+        year = start.strftime("%Y")
+
+        if groupby is None:
+            groupby = {}
+
+        groupby['week_of_the_year'] = week_of_the_year
+        groupby['day_of_the_year'] = day_of_the_year
+        groupby['month'] = month_of_the_year
+        groupby['year'] = year
+
+        return DataPoint(unit, qty, price, groupby, metadata,
+                         metric.get('description'))
+
 
 class InvalidConfiguration(Exception):
     pass
