@@ -400,7 +400,7 @@ class Worker(BaseWorker):
         return True
 
     def do_execute_scope_processing(self, timestamp):
-        metrics = list(self._conf['metrics'].keys())
+        metrics = list(self._collector.conf.keys())
         # Collection
         metrics = sorted(metrics)
         usage_data = self._do_collection(metrics, timestamp)
@@ -517,13 +517,27 @@ class ReprocessingWorker(Worker):
 
         end_of_this_processing = tzutils.local_to_utc(end_of_this_processing)
 
-        LOG.debug("Cleaning backend [%s] data for reprocessing scope [%s] "
-                  "for timeframe[start=%s, end=%s].",
-                  self._storage, self.scope, timestamp, end_of_this_processing)
-
-        self._storage.delete(
-            begin=timestamp, end=end_of_this_processing,
-            filters={self.scope_key: self._tenant_id})
+        # If the start_reprocess_time of the reprocessing task equals to
+        # the current reprocessing time, it means that we have just started
+        # executing it. Therefore, we can clean/erase the old data in the
+        # reprocessing task time frame.
+        if tzutils.local_to_utc(self.scope.start_reprocess_time) == timestamp:
+            LOG.info(
+                "Cleaning backend [%s] data for reprocessing scope [%s] for "
+                "timeframe[start=%s, end=%s].", self._storage, self.scope,
+                self.scope.start_reprocess_time, self.scope.end_reprocess_time)
+            self._storage.delete(
+                begin=self.scope.start_reprocess_time,
+                end=self.scope.end_reprocess_time,
+                filters={self.scope_key: self._tenant_id})
+        else:
+            LOG.debug("No need to clean backend [%s] data for reprocessing "
+                      "scope [%s] for timeframe[start=%s, end=%s]. We are "
+                      "past the very first timestamp; therefore, the cleaning "
+                      "for the reprocessing task period has already been "
+                      "executed.", self._storage, self.scope,
+                      self.scope.start_reprocess_time,
+                      self.scope.end_reprocess_time)
 
         LOG.debug("Executing the reprocessing of scope [%s] for "
                   "timeframe[start=%s, end=%s].", self.scope, timestamp,
@@ -614,13 +628,17 @@ class CloudKittyProcessor(cotyledon.Service):
             lock_name, lock = get_lock(
                 self.coord, self.generate_lock_base_name(tenant_id))
 
-            LOG.debug('[Worker: {w}] Trying to acquire lock "{lock_name}".'
-                      .format(w=self._worker_id, lock_name=lock_name))
+            LOG.debug('[Worker: {w}] Trying to acquire lock "{lock_name}" for '
+                      'scope ID {scope_id}.'.format(w=self._worker_id,
+                                                    lock_name=lock_name,
+                                                    scope_id=tenant_id))
 
             lock_acquired = lock.acquire(blocking=False)
             if lock_acquired:
-                LOG.debug('[Worker: {w}] Acquired lock "{lock_name}".'.format(
-                    w=self._worker_id, lock_name=lock_name))
+                LOG.debug('[Worker: {w}] Acquired lock "{lock_name}" for '
+                          'scope ID {scope_id}.'.format(w=self._worker_id,
+                                                        lock_name=lock_name,
+                                                        scope_id=tenant_id))
 
                 try:
                     self.process_scope(tenant_id)
@@ -702,9 +720,10 @@ class CloudKittyReprocessor(CloudKittyProcessor):
                  self._worker_id, len(self.tenants))
 
     def generate_lock_base_name(self, scope):
-        return "%s-id=%s-start=%s-end=%s-current=%s" % (
-            self.worker_class, scope.identifier, scope.start_reprocess_time,
-            scope.end_reprocess_time, scope.current_reprocess_time)
+        return "%s-id=%s-start=%s-end=%s" % (self.worker_class,
+                                             scope.identifier,
+                                             scope.start_reprocess_time,
+                                             scope.end_reprocess_time)
 
 
 class CloudKittyServiceManager(cotyledon.ServiceManager):
