@@ -416,8 +416,7 @@ class WorkerTest(tests.TestCase):
         ])
         self.assertTrue(update_scope_processing_state_db_mock.called)
 
-    @mock.patch("cloudkitty.storage_state.StateManager"
-                ".get_last_processed_timestamp")
+    @mock.patch("cloudkitty.storage_state.StateManager.get_state")
     @mock.patch("cloudkitty.storage_state.StateManager"
                 ".is_storage_scope_active")
     @mock.patch("cloudkitty.orchestrator.Worker.do_execute_scope_processing")
@@ -439,8 +438,7 @@ class WorkerTest(tests.TestCase):
         self.assertFalse(do_execute_scope_processing_mock.called)
         self.assertTrue(next_timestamp_to_process_mock.called)
 
-    @mock.patch("cloudkitty.storage_state.StateManager"
-                ".get_last_processed_timestamp")
+    @mock.patch("cloudkitty.storage_state.StateManager.get_state")
     @mock.patch("cloudkitty.storage_state.StateManager"
                 ".is_storage_scope_active")
     @mock.patch("cloudkitty.orchestrator.Worker.do_execute_scope_processing")
@@ -470,8 +468,7 @@ class WorkerTest(tests.TestCase):
         self.assertFalse(state_manager_is_storage_scope_active_mock.called)
         self.assertTrue(next_timestamp_to_process_mock.called)
 
-    @mock.patch("cloudkitty.storage_state.StateManager"
-                ".get_last_processed_timestamp")
+    @mock.patch("cloudkitty.storage_state.StateManager.get_state")
     @mock.patch("cloudkitty.storage_state.StateManager"
                 ".is_storage_scope_active")
     @mock.patch("cloudkitty.orchestrator.Worker.do_execute_scope_processing")
@@ -506,8 +503,7 @@ class WorkerTest(tests.TestCase):
 
         self.assertTrue(next_timestamp_to_process_mock.called)
 
-    @mock.patch("cloudkitty.storage_state.StateManager"
-                ".get_last_processed_timestamp")
+    @mock.patch("cloudkitty.storage_state.StateManager.get_state")
     @mock.patch("cloudkitty.storage_state.StateManager"
                 ".is_storage_scope_active")
     @mock.patch("cloudkitty.orchestrator.Worker.do_execute_scope_processing")
@@ -592,8 +588,7 @@ class WorkerTest(tests.TestCase):
         state_mock = mock.Mock()
 
         timestamp_now = tzutils.localized_now()
-        state_mock._state.get_last_processed_timestamp.return_value = \
-            timestamp_now
+        state_mock._state.get_state.return_value = timestamp_now
 
         expected_time = timestamp_now + datetime.timedelta(hours=1)
         check_time_state_mock.return_value = \
@@ -604,7 +599,7 @@ class WorkerTest(tests.TestCase):
 
         self.assertEqual(expected_time, return_of_method)
 
-        state_mock._state.get_last_processed_timestamp.assert_has_calls([
+        state_mock._state.get_state.assert_has_calls([
             mock.call(self._tenant_id)])
         check_time_state_mock.assert_has_calls([
             mock.call(timestamp_now, 3600, 2)])
@@ -628,10 +623,9 @@ class CloudKittyReprocessorTest(tests.TestCase):
 
         expected_lock_name = "<class 'cloudkitty.orchestrator." \
                              "ReprocessingWorker'>-id=scope_identifier-" \
-                             "start=%s-end=%s-current=%s" % (
+                             "start=%s-end=%s" % (
                                  scope_mock.start_reprocess_time,
-                                 scope_mock.end_reprocess_time,
-                                 scope_mock.current_reprocess_time)
+                                 scope_mock.end_reprocess_time)
 
         self.assertEqual(expected_lock_name, return_generate_lock_name)
 
@@ -1040,15 +1034,16 @@ class ReprocessingWorkerTest(tests.TestCase):
             self, do_execute_scope_processing_mock_from_worker):
 
         now_timestamp = tzutils.localized_now()
+        self.reprocessing_worker.scope.start_reprocess_time = now_timestamp
         self.reprocessing_worker.do_execute_scope_processing(now_timestamp)
 
-        expected_end = tzutils.localized_now() + datetime.timedelta(
-            seconds=self.reprocessing_worker._period)
-
         self.storage_mock.delete.assert_has_calls([
-            mock.call(begin=now_timestamp, end=expected_end,
-                      filters={self.reprocessing_worker.scope_key:
-                               self.reprocessing_worker._tenant_id})])
+            mock.call(
+                begin=self.reprocessing_worker.scope.start_reprocess_time,
+                end=self.reprocessing_worker.scope.end_reprocess_time,
+                filters={
+                    self.reprocessing_worker.scope_key:
+                        self.reprocessing_worker._tenant_id})])
 
         do_execute_scope_processing_mock_from_worker.assert_has_calls([
             mock.call(now_timestamp)])
