@@ -13,17 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
-# @author: Gauvain Pocentek
-#
 import datetime
-import testtools
 
 from cloudkitty import state
 from cloudkitty import tests
-from cloudkitty.tests.utils import is_functional_test
 
 
-@testtools.skipIf(is_functional_test(), 'Not a functional test')
 class DBStateManagerTest(tests.TestCase):
     def setUp(self):
         super(DBStateManagerTest, self).setUp()
